@@ -1,11 +1,9 @@
 import logging
 
+
 def setup():
     logging.basicConfig(
         level=logging.INFO,
         format="%(asctime)s [%(levelname)s] %(message)s",
-        handlers=[
-            logging.FileHandler("debug.log"),
-            logging.StreamHandler()
-        ]
+        handlers=[logging.FileHandler("debug.log"), logging.StreamHandler()],
     )
